@@ -5,6 +5,7 @@ import doctest
 from trytond.tests.test_tryton import suite as test_suite
 from trytond.tests.test_tryton import ModuleTestCase
 from trytond.tests.test_tryton import doctest_setup, doctest_teardown
+from trytond.tests.test_tryton import doctest_checker
 
 
 class AccountDepositTestCase(ModuleTestCase):
@@ -18,5 +19,6 @@ def suite():
             AccountDepositTestCase))
     suite.addTests(doctest.DocFileSuite('scenario_deposit.rst',
             setUp=doctest_setup, tearDown=doctest_teardown, encoding='utf-8',
+            checker=doctest_checker,
             optionflags=doctest.REPORT_ONLY_FIRST_FAILURE))
     return suite
